## pyncp
---
Python библиотека протокола NCP
---

# Сборка

1) Перейти в корневую директорию проекта
2) Выполнить команду:
python setup.py sdist

# Установка

1) Перейти в корневую директорию проекта
2) Выполнить команду:
pip install dist/pyncp-x.x.x.tar.gz

# Примеры

|Файл  |Описание  |
|---------|---------|
|encode_decode.py | Кодирование DATA запроса + декодирование DATA ответа |